Esta páxina cont&eacute;n un sumario das solicitudes administrativas que
requiren da s&uacute;a aprobación para a <a href="%(adminurl)s">rolda de
distribución</em>
<em>%(listname)s</em></a>.

O primeiro que atopar&aacute; serán as solicitudes de alta e de baixa
na rolda,
sempre
que existir algunha, seguida por calquera envío &aacute; rolda que precisar
da s&uacute;a
aprobación.

<p>Seleccione a acción que se debe tomar para cada unha das solicitudes administrativas
  e
prema o botón <b>Enviar todos os datos</b> logo de rematar.
Pode ver aqu&iacute; unhas <a href="%(detailsurl)s">instruci&oacute;ns máis detalladas</a>.

<p>Tamén pode <a href="%(viewallurl)s">ver os detalles</a> de todos os
  envíos
retidos.
